@@ -11,20 +11,23 @@ def main(
     table_path: str,
 ):
     df = pl.read_csv(table_path)
-    ord = {e: i for i, e in enumerate([
-            "Setting",
-            "# Clusters",
-            "Node cov.",
-            "Edge cov.",
-            "High deg. singletons",
-            "Cluster Size",
-            "MCD",
-            "Connectivity",
-            "Cut Size",
-        ])}
-    df = df.select(
-        sorted(df.columns, key=lambda c: ord.get(c, 99))
-    )
+    ord = {
+        e: i
+        for i, e in enumerate(
+            [
+                "Setting",
+                "# Clusters",
+                "Node cov.",
+                "Edge cov.",
+                "High deg. singletons",
+                "Cluster Size",
+                "MCD",
+                "Connectivity",
+                "Cut Size",
+            ]
+        )
+    }
+    df = df.select(sorted(df.columns, key=lambda c: ord.get(c, 99)))
     print(
         df.to_pandas().to_latex(
             formatters={
