@@ -100,7 +100,7 @@ def main(
             size_lb_bounds.append(size_lb)
         for s in size_lb_bounds:
             stats = basic_statistics(g, c.filter(pl.col('n') > s), overlap, numvalues)
-            stats = stats.with_column(pl.lit(l + f">= {s}" if s > 0 else "").alias("Setting"))
+            stats = stats.with_column(pl.lit(l + (f">= {s}" if s > 0 else "")).alias("Setting"))
             dfs.append(stats)
     df = pl.concat(dfs)
     logger.info("Computed statistics", num_variants=len(df))
